-- Chapter 10 Oracle Examples
-- DROP VIEW statements are provided to allow the view to be created more than one time.
-- Examples 10.1 to 10.18 use the university database introduced in Chapter 4
-- Examples 10.34 and 10.35 use the revised university database introduced in Chapter 10.4

10.1
DROP VIEW IS_View;

CREATE VIEW IS_View AS
 SELECT * FROM Student
  WHERE StdMajor = 'IS'
/

10.2
DROP VIEW MS_View;

CREATE VIEW MS_View AS
 SELECT OfferNo, Offering.CourseNo, CrsUnits, OffTerm,
        OffYear, Offering.FacSSN, FacFirstName,
        FacLastName, OffTime, OffDays
  FROM Faculty, Course, Offering
  WHERE FacDept = 'MS' 
    AND Faculty.FacSSN = Offering.FacSSN
	 AND Offering.CourseNo = Course.CourseNo
/

10.3
DROP VIEW Enrollment_View;

CREATE VIEW  Enrollment_View
(OfferNo, CourseNo, Term, Year, Instructor, NumStudents) 
 AS
 SELECT Offering.OfferNo, CourseNo, OffTerm, OffYear,
        FacLastName, COUNT(*)
  FROM Offering, Faculty, Enrollment
  WHERE  Offering.FacSSN  =  Faculty.FacSSN
    AND Offering.OfferNo  =  Enrollment.OfferNo
  GROUP BY Offering.OfferNo, CourseNo, OffTerm, OffYear, 
           FacLastName
/

10.4
SELECT OfferNo, CourseNo, FacFirstName, FacLastName,
       OffTime, OffDays
 FROM MS_View
 WHERE OffTerm = 'SPRING' AND OffYear = 2006
/

10.5
SELECT OfferNo, CourseNo, Instructor, NumStudents
 FROM Enrollment_View
 WHERE Term = 'SPRING' AND Year = 2006 
   AND CourseNo LIKE 'IS%'
/

10.6
SELECT Instructor, AVG(NumStudents) AS AvgStdCount
 FROM Enrollment_View
 GROUP BY Instructor
/

10.7
SELECT OfferNo, Instructor, NumStudents, CrsUnits
 FROM Enrollment_View, Course
 WHERE Enrollment_View.CourseNo = Course.CourseNo 
   AND NumStudents < 5
/

10.8
SELECT OfferNo, CourseNo, FacFirstName, FacLastName,
       OffTime, OffDays
 FROM MS_View
 WHERE OffTerm = 'SPRING' AND OffYear = 2006
/

10.9
SELECT OfferNo, Course.CourseNo, FacFirstName,
       FacLastName, OffTime, OffDays
 FROM Faculty, Course, Offering
 WHERE FacDept = 'MS' 
   AND Faculty.FacSSN = Offering.FacSSN
	AND Offering.CourseNo = Course.CourseNo 
	AND OffTerm = 'SPRING' AND OffYear = 2006
/

10.10
SELECT OfferNo, CourseNo, FacFirstName, FacLastName,
       OffTime, OffDays
 FROM Faculty, Offering
 WHERE FacDept = 'MS' 
   AND Faculty.FacSSN = Offering.FacSSN
	AND OffTerm = 'SPRING' AND OffYear = 2006
/

10.11
CREATE VIEW Fac_View1 AS 
 SELECT FacSSN, FacFirstName, FacLastName, FacRank,
        FacSalary, FacDept, FacCity, FacState, FacZipCode
  FROM Faculty
  WHERE FacDept = 'MS'
/

10.12
CREATE VIEW Fac_View2 AS 
 SELECT FacDept, FacRank, FacSalary 
  FROM Faculty
  WHERE FacSalary > 50000
/

10.13
CREATE View Fac_View3 (FacDept, AvgSalary) AS 
 SELECT FacDept, AVG(FacSalary) 
  FROM Faculty
  WHERE FacRank = 'PROF'
  GROUP BY FacDept
/

10.14
INSERT INTO Fac_View1 
 (FacSSN, FacFirstName, FacLastName, FacRank, FacSalary,
  FacDept, FacCity, FacState, FacZipCode)
 VALUES ('999-99-8888', 'JOE', 'SMITH', 'PROF', 80000,
         'MS', 'SEATTLE', 'WA', '98011-011')
/

10.15
UPDATE Fac_View1 
 SET FacSalary = FacSalary * 1.1
 WHERE FacRank = 'ASST'
/

10.16
DELETE FROM Fac_View1
 WHERE FacSSN = '098-76-5432'
/

10.17
UPDATE Fac_View1 
 SET FacDept = 'FIN'
 WHERE FacSalary > 100000
/

10.18
CREATE VIEW Fac_View1_Revised AS 
 SELECT FacSSN, FacFirstName, FacLastName, FacRank,
        FacSalary, FacDept, FacCity, FacState, FacZipCode
  FROM Faculty
  WHERE FacDept = 'MS'
 WITH CHECK OPTION
/

UPDATE Fac_View1_Revised 
 SET FacDept = 'FIN'
 WHERE FacSalary > 100000
/

-- Examples 10.34 and 10.35 use the revised university database introduced in Section 10.4
10.34
SELECT Faculty.FacSSN, Faculty.FacFirstName, FacLastName,
       Faculty.FacDept, Offering.OfferNo,
       Offering.CourseNo, Offering.OffTerm,
       Offering.OffYear, Offering.OffLocation,
       Offering.OffTime, Offering.OffDays
 FROM Faculty, Offering
 WHERE Faculty.FacSSN = Offering.FacSSN
   AND ( ( Offering.OffTerm = 'FALL' 
   AND Offering.OffYear = 2005 ) 
    OR ( Offering.OffTerm = 'WINTER' 
   AND Offering.OffYear = 2006 ) 
    OR ( Offering.OffTerm = 'SPRING' 
   AND Offering.OffYear = 2006 ) )
/

10.35
SELECT Offering.OfferNo, FacFirstName, FacLastName,
       FacDept, OffTerm, CrsUnits, OffLimit,
       Count(Enrollment.RegNo) AS NumStds, 
       NumStds/Offlimit AS PercentFull, 
       (NumStds/Offlimit) < 0.25 AS LowEnrollment
 FROM Faculty, Offering, Course, Enrollment
 WHERE Faculty.FacSSN = Offering.FacSSN 
   AND Course.CourseNo = Offering.CourseNo
   AND Offering.OfferNo = Enrollment.OfferNo
   AND ( ( Offering.OffTerm = 'FALL' 
   AND Offering.OffYear = 2005 ) 
    OR ( Offering.OffTerm = 'WINTER' 
          AND Offering.OffYear = 2006 ) 
    OR ( Offering.OffTerm = 'SPRING' 
   AND Offering.OffYear = 2006 ) )
 GROUP BY Offering.OfferNo, FacFirstName, FacLastName,
          FacDept, OffTerm, CrsUnits, OffLimit
/